/**
 * \file src/gui/xic_view/xicwindow.cpp
 * \date 11/1/2018
 * \author Olivier Langella
 * \brief XIC window
 */

/*******************************************************************************
* Copyright (c) 2018 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/

#include "xicwindow.h"
#include "ui_xic_window.h"
#include "../project_view/projectwindow.h"
#include "xic_box/xicbox.h"

XicWindow::XicWindow(ProjectWindow *parent):
    QMainWindow(parent),
    ui(new Ui::XicWindow)
{
    _project_window = parent;

    ui->setupUi(this);

    QSettings settings;
    QString precision_str = settings.value("xic/precision", "10 ppm").toString();

    ui->xic_precision->setPrecision(pappso::Precision::fromString(precision_str));

    _detect_zivy.setSmoothingHalfEdgeWindows(settings.value("xic/zivy_smoothing", "1").toInt());
    _detect_zivy.setMinMaxHalfEdgeWindows(settings.value("xic/zivy_minmax_half_window", "3").toInt());
    _detect_zivy.setMaxMinHalfEdgeWindows(settings.value("xic/zivy_maxmin_half_window", "2").toInt());
    _detect_zivy.setDetectionThresholdOnMinmax(settings.value("xic/zivy_minmax_threshold", "5000").toDouble());
    _detect_zivy.setDetectionThresholdOnMaxmin(settings.value("xic/zivy_maxmin_threshold", "3000").toDouble());


#if QT_VERSION >= 0x050000
    // Qt5 code

#else
// Qt4 code
#endif


}

XicWindow::~XicWindow()
{
    qDebug() << "XicWindow::~XicWindow";
}

void XicWindow::clear() {
    QLayoutItem *wItem;
    while (wItem = ui->xic_vertical_layout->layout()->takeAt(0)) {
        wItem->widget()->setVisible(false);
        ui->xic_vertical_layout->layout()->removeWidget(wItem->widget());
        delete wItem->widget();
    }
}

ProjectWindow * XicWindow::getProjectWindow() {
    return _project_window;
}
void XicWindow::addXic(const PeptideEvidence * p_peptide_evidence) {
    XicBox * p_box = new XicBox(this);
    p_box->setPeptideEvidence(p_peptide_evidence);
    ui->xic_vertical_layout->layout()->addWidget(p_box);
}

void XicWindow::addXicInMsRun(const PeptideEvidence * p_peptide_evidence, MsRunSp msrun_sp) {
    XicBox * p_box = new XicBox(this);
    p_box->setPeptideEvidenceInMsRun(p_peptide_evidence, msrun_sp);
    ui->xic_vertical_layout->layout()->addWidget(p_box);
}

void XicWindow::removeXicBox(XicBox * xic_box) {
    xic_box->setVisible(false);
    ui->xic_vertical_layout->layout()->removeWidget(xic_box);
    delete xic_box;
}

pappso::PrecisionP XicWindow::getXicExtractPrecision() const {
    return (ui->xic_precision->getPrecision());
}

void XicWindow::xicPrecisionChanged(pappso::PrecisionP precision) {
    qDebug() << "XicWindow::xicPrecisionChanged begin";
    qDebug() << "XicWindow::xicPrecisionChanged emit";
    emit reExtractXicNeeded();
    qDebug() << "XicWindow::xicPrecisionChanged end";
}

void XicWindow::xicDetect(const pappso::Xic & xic,pappso::XicDetectionSinkInterface * sink) const {
    _detect_zivy.detect(xic, sink);
}

void XicWindow::rtUnitChanged(QAbstractButton* button) {
    qDebug() << "XicWindow::rtUnitChanged begin";
    emit rtUnitChangeNeeded();
    qDebug() << "XicWindow::rtUnitChanged end";
}

bool XicWindow::isRetentionTimeSeconds() const {
    if (ui->rt_sec_radiobutton->isChecked()) {
        return true;
    }
    return false;
}
